# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.3.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKClassifiersPython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _itkBayesianClassifierInitializationImageFilterPython
else:
    import _itkBayesianClassifierInitializationImageFilterPython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.ITKCommonBasePython
import itk.itkMatrixPython
import itk.itkVectorPython
import itk.vnl_vectorPython
import itk.stdcomplexPython
import itk.pyBasePython
import itk.vnl_matrixPython
import itk.itkFixedArrayPython
import itk.vnl_vector_refPython
import itk.itkPointPython
import itk.itkCovariantVectorPython
import itk.vnl_matrix_fixedPython
import itk.itkImageToImageFilterBPython
import itk.itkPhasedArray3DSpecialCoordinatesImagePython
import itk.itkIndexPython
import itk.itkSizePython
import itk.itkOffsetPython
import itk.itkImagePython
import itk.itkRGBPixelPython
import itk.itkImageRegionPython
import itk.itkRGBAPixelPython
import itk.itkSymmetricSecondRankTensorPython
import itk.itkVectorImagePython
import itk.itkVariableLengthVectorPython
import itk.itkImageToImageFilterCommonPython
import itk.itkImageSourcePython
import itk.itkImageSourceCommonPython

def itkBayesianClassifierInitializationImageFilterIF2F_New():
    return itkBayesianClassifierInitializationImageFilterIF2F.New()

class itkBayesianClassifierInitializationImageFilterIF2F(itk.itkImageToImageFilterBPython.itkImageToImageFilterIF2VIF2):
    r"""Proxy of C++ itkBayesianClassifierInitializationImageFilterIF2F class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkBayesianClassifierInitializationImageFilterIF2F_Pointer"""
        return _itkBayesianClassifierInitializationImageFilterPython.itkBayesianClassifierInitializationImageFilterIF2F___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkBayesianClassifierInitializationImageFilterIF2F_Pointer"""
        return _itkBayesianClassifierInitializationImageFilterPython.itkBayesianClassifierInitializationImageFilterIF2F_Clone(self)

    def SetMembershipFunctions(self, membershipFunction):
        r"""
        SetMembershipFunctions(self, membershipFunction)

        Parameters
        ----------
        membershipFunction: itk::VectorContainer< unsigned int,itk::SmartPointer< itk::Statistics::MembershipFunctionBase< itk::Vector< float,1 > > > > *

        """
        return _itkBayesianClassifierInitializationImageFilterPython.itkBayesianClassifierInitializationImageFilterIF2F_SetMembershipFunctions(self, membershipFunction)

    def GetModifiableMembershipFunctionContainer(self):
        r"""GetModifiableMembershipFunctionContainer(self) -> itk::VectorContainer< unsigned int,itk::SmartPointer< itk::Statistics::MembershipFunctionBase< itk::Vector< float,1 > > > > *"""
        return _itkBayesianClassifierInitializationImageFilterPython.itkBayesianClassifierInitializationImageFilterIF2F_GetModifiableMembershipFunctionContainer(self)

    def GetMembershipFunctionContainer(self, *args):
        r"""
        GetMembershipFunctionContainer(self) -> itk::VectorContainer< unsigned int,itk::SmartPointer< itk::Statistics::MembershipFunctionBase< itk::Vector< float,1 > > > > const
        GetMembershipFunctionContainer(self) -> itk::VectorContainer< unsigned int,itk::SmartPointer< itk::Statistics::MembershipFunctionBase< itk::Vector< float,1 > > > > *
        """
        return _itkBayesianClassifierInitializationImageFilterPython.itkBayesianClassifierInitializationImageFilterIF2F_GetMembershipFunctionContainer(self, *args)

    def SetNumberOfClasses(self, _arg):
        r"""
        SetNumberOfClasses(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        """
        return _itkBayesianClassifierInitializationImageFilterPython.itkBayesianClassifierInitializationImageFilterIF2F_SetNumberOfClasses(self, _arg)

    def GetNumberOfClasses(self):
        r"""GetNumberOfClasses(self) -> unsigned int"""
        return _itkBayesianClassifierInitializationImageFilterPython.itkBayesianClassifierInitializationImageFilterIF2F_GetNumberOfClasses(self)

    def GenerateOutputInformation(self):
        r"""GenerateOutputInformation(self)"""
        return _itkBayesianClassifierInitializationImageFilterPython.itkBayesianClassifierInitializationImageFilterIF2F_GenerateOutputInformation(self)
    InputMultiplyOperatorCheck = _itkBayesianClassifierInitializationImageFilterPython.itkBayesianClassifierInitializationImageFilterIF2F_InputMultiplyOperatorCheck
    
    DoubleConvertibleToProbabilityCheck = _itkBayesianClassifierInitializationImageFilterPython.itkBayesianClassifierInitializationImageFilterIF2F_DoubleConvertibleToProbabilityCheck
    
    InputHasNumericTraitsCheck = _itkBayesianClassifierInitializationImageFilterPython.itkBayesianClassifierInitializationImageFilterIF2F_InputHasNumericTraitsCheck
    
    ProbabilityHasNumericTraitsCheck = _itkBayesianClassifierInitializationImageFilterPython.itkBayesianClassifierInitializationImageFilterIF2F_ProbabilityHasNumericTraitsCheck
    
    DoublePlusInputCheck = _itkBayesianClassifierInitializationImageFilterPython.itkBayesianClassifierInitializationImageFilterIF2F_DoublePlusInputCheck
    
    __swig_destroy__ = _itkBayesianClassifierInitializationImageFilterPython.delete_itkBayesianClassifierInitializationImageFilterIF2F

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkBayesianClassifierInitializationImageFilterIF2F

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkBayesianClassifierInitializationImageFilterPython.itkBayesianClassifierInitializationImageFilterIF2F_cast(obj)

    def New(*args, **kargs):
        """New() -> itkBayesianClassifierInitializationImageFilterIF2F

        Create a new object of the class itkBayesianClassifierInitializationImageFilterIF2F and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkBayesianClassifierInitializationImageFilterIF2F.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkBayesianClassifierInitializationImageFilterIF2F.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkBayesianClassifierInitializationImageFilterIF2F.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkBayesianClassifierInitializationImageFilterIF2F in _itkBayesianClassifierInitializationImageFilterPython:
_itkBayesianClassifierInitializationImageFilterPython.itkBayesianClassifierInitializationImageFilterIF2F_swigregister(itkBayesianClassifierInitializationImageFilterIF2F)

def itkBayesianClassifierInitializationImageFilterIF3F_New():
    return itkBayesianClassifierInitializationImageFilterIF3F.New()

class itkBayesianClassifierInitializationImageFilterIF3F(itk.itkImageToImageFilterBPython.itkImageToImageFilterIF3VIF3):
    r"""Proxy of C++ itkBayesianClassifierInitializationImageFilterIF3F class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkBayesianClassifierInitializationImageFilterIF3F_Pointer"""
        return _itkBayesianClassifierInitializationImageFilterPython.itkBayesianClassifierInitializationImageFilterIF3F___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkBayesianClassifierInitializationImageFilterIF3F_Pointer"""
        return _itkBayesianClassifierInitializationImageFilterPython.itkBayesianClassifierInitializationImageFilterIF3F_Clone(self)

    def SetMembershipFunctions(self, membershipFunction):
        r"""
        SetMembershipFunctions(self, membershipFunction)

        Parameters
        ----------
        membershipFunction: itk::VectorContainer< unsigned int,itk::SmartPointer< itk::Statistics::MembershipFunctionBase< itk::Vector< float,1 > > > > *

        """
        return _itkBayesianClassifierInitializationImageFilterPython.itkBayesianClassifierInitializationImageFilterIF3F_SetMembershipFunctions(self, membershipFunction)

    def GetModifiableMembershipFunctionContainer(self):
        r"""GetModifiableMembershipFunctionContainer(self) -> itk::VectorContainer< unsigned int,itk::SmartPointer< itk::Statistics::MembershipFunctionBase< itk::Vector< float,1 > > > > *"""
        return _itkBayesianClassifierInitializationImageFilterPython.itkBayesianClassifierInitializationImageFilterIF3F_GetModifiableMembershipFunctionContainer(self)

    def GetMembershipFunctionContainer(self, *args):
        r"""
        GetMembershipFunctionContainer(self) -> itk::VectorContainer< unsigned int,itk::SmartPointer< itk::Statistics::MembershipFunctionBase< itk::Vector< float,1 > > > > const
        GetMembershipFunctionContainer(self) -> itk::VectorContainer< unsigned int,itk::SmartPointer< itk::Statistics::MembershipFunctionBase< itk::Vector< float,1 > > > > *
        """
        return _itkBayesianClassifierInitializationImageFilterPython.itkBayesianClassifierInitializationImageFilterIF3F_GetMembershipFunctionContainer(self, *args)

    def SetNumberOfClasses(self, _arg):
        r"""
        SetNumberOfClasses(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        """
        return _itkBayesianClassifierInitializationImageFilterPython.itkBayesianClassifierInitializationImageFilterIF3F_SetNumberOfClasses(self, _arg)

    def GetNumberOfClasses(self):
        r"""GetNumberOfClasses(self) -> unsigned int"""
        return _itkBayesianClassifierInitializationImageFilterPython.itkBayesianClassifierInitializationImageFilterIF3F_GetNumberOfClasses(self)

    def GenerateOutputInformation(self):
        r"""GenerateOutputInformation(self)"""
        return _itkBayesianClassifierInitializationImageFilterPython.itkBayesianClassifierInitializationImageFilterIF3F_GenerateOutputInformation(self)
    InputMultiplyOperatorCheck = _itkBayesianClassifierInitializationImageFilterPython.itkBayesianClassifierInitializationImageFilterIF3F_InputMultiplyOperatorCheck
    
    DoubleConvertibleToProbabilityCheck = _itkBayesianClassifierInitializationImageFilterPython.itkBayesianClassifierInitializationImageFilterIF3F_DoubleConvertibleToProbabilityCheck
    
    InputHasNumericTraitsCheck = _itkBayesianClassifierInitializationImageFilterPython.itkBayesianClassifierInitializationImageFilterIF3F_InputHasNumericTraitsCheck
    
    ProbabilityHasNumericTraitsCheck = _itkBayesianClassifierInitializationImageFilterPython.itkBayesianClassifierInitializationImageFilterIF3F_ProbabilityHasNumericTraitsCheck
    
    DoublePlusInputCheck = _itkBayesianClassifierInitializationImageFilterPython.itkBayesianClassifierInitializationImageFilterIF3F_DoublePlusInputCheck
    
    __swig_destroy__ = _itkBayesianClassifierInitializationImageFilterPython.delete_itkBayesianClassifierInitializationImageFilterIF3F

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkBayesianClassifierInitializationImageFilterIF3F

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkBayesianClassifierInitializationImageFilterPython.itkBayesianClassifierInitializationImageFilterIF3F_cast(obj)

    def New(*args, **kargs):
        """New() -> itkBayesianClassifierInitializationImageFilterIF3F

        Create a new object of the class itkBayesianClassifierInitializationImageFilterIF3F and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkBayesianClassifierInitializationImageFilterIF3F.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkBayesianClassifierInitializationImageFilterIF3F.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkBayesianClassifierInitializationImageFilterIF3F.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkBayesianClassifierInitializationImageFilterIF3F in _itkBayesianClassifierInitializationImageFilterPython:
_itkBayesianClassifierInitializationImageFilterPython.itkBayesianClassifierInitializationImageFilterIF3F_swigregister(itkBayesianClassifierInitializationImageFilterIF3F)

def itkBayesianClassifierInitializationImageFilterISS2F_New():
    return itkBayesianClassifierInitializationImageFilterISS2F.New()

class itkBayesianClassifierInitializationImageFilterISS2F(itk.itkImageToImageFilterBPython.itkImageToImageFilterISS2VIF2):
    r"""Proxy of C++ itkBayesianClassifierInitializationImageFilterISS2F class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkBayesianClassifierInitializationImageFilterISS2F_Pointer"""
        return _itkBayesianClassifierInitializationImageFilterPython.itkBayesianClassifierInitializationImageFilterISS2F___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkBayesianClassifierInitializationImageFilterISS2F_Pointer"""
        return _itkBayesianClassifierInitializationImageFilterPython.itkBayesianClassifierInitializationImageFilterISS2F_Clone(self)

    def SetMembershipFunctions(self, membershipFunction):
        r"""
        SetMembershipFunctions(self, membershipFunction)

        Parameters
        ----------
        membershipFunction: itk::VectorContainer< unsigned int,itk::SmartPointer< itk::Statistics::MembershipFunctionBase< itk::Vector< short,1 > > > > *

        """
        return _itkBayesianClassifierInitializationImageFilterPython.itkBayesianClassifierInitializationImageFilterISS2F_SetMembershipFunctions(self, membershipFunction)

    def GetModifiableMembershipFunctionContainer(self):
        r"""GetModifiableMembershipFunctionContainer(self) -> itk::VectorContainer< unsigned int,itk::SmartPointer< itk::Statistics::MembershipFunctionBase< itk::Vector< short,1 > > > > *"""
        return _itkBayesianClassifierInitializationImageFilterPython.itkBayesianClassifierInitializationImageFilterISS2F_GetModifiableMembershipFunctionContainer(self)

    def GetMembershipFunctionContainer(self, *args):
        r"""
        GetMembershipFunctionContainer(self) -> itk::VectorContainer< unsigned int,itk::SmartPointer< itk::Statistics::MembershipFunctionBase< itk::Vector< short,1 > > > > const
        GetMembershipFunctionContainer(self) -> itk::VectorContainer< unsigned int,itk::SmartPointer< itk::Statistics::MembershipFunctionBase< itk::Vector< short,1 > > > > *
        """
        return _itkBayesianClassifierInitializationImageFilterPython.itkBayesianClassifierInitializationImageFilterISS2F_GetMembershipFunctionContainer(self, *args)

    def SetNumberOfClasses(self, _arg):
        r"""
        SetNumberOfClasses(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        """
        return _itkBayesianClassifierInitializationImageFilterPython.itkBayesianClassifierInitializationImageFilterISS2F_SetNumberOfClasses(self, _arg)

    def GetNumberOfClasses(self):
        r"""GetNumberOfClasses(self) -> unsigned int"""
        return _itkBayesianClassifierInitializationImageFilterPython.itkBayesianClassifierInitializationImageFilterISS2F_GetNumberOfClasses(self)

    def GenerateOutputInformation(self):
        r"""GenerateOutputInformation(self)"""
        return _itkBayesianClassifierInitializationImageFilterPython.itkBayesianClassifierInitializationImageFilterISS2F_GenerateOutputInformation(self)
    InputMultiplyOperatorCheck = _itkBayesianClassifierInitializationImageFilterPython.itkBayesianClassifierInitializationImageFilterISS2F_InputMultiplyOperatorCheck
    
    DoubleConvertibleToProbabilityCheck = _itkBayesianClassifierInitializationImageFilterPython.itkBayesianClassifierInitializationImageFilterISS2F_DoubleConvertibleToProbabilityCheck
    
    InputHasNumericTraitsCheck = _itkBayesianClassifierInitializationImageFilterPython.itkBayesianClassifierInitializationImageFilterISS2F_InputHasNumericTraitsCheck
    
    ProbabilityHasNumericTraitsCheck = _itkBayesianClassifierInitializationImageFilterPython.itkBayesianClassifierInitializationImageFilterISS2F_ProbabilityHasNumericTraitsCheck
    
    DoublePlusInputCheck = _itkBayesianClassifierInitializationImageFilterPython.itkBayesianClassifierInitializationImageFilterISS2F_DoublePlusInputCheck
    
    __swig_destroy__ = _itkBayesianClassifierInitializationImageFilterPython.delete_itkBayesianClassifierInitializationImageFilterISS2F

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkBayesianClassifierInitializationImageFilterISS2F

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkBayesianClassifierInitializationImageFilterPython.itkBayesianClassifierInitializationImageFilterISS2F_cast(obj)

    def New(*args, **kargs):
        """New() -> itkBayesianClassifierInitializationImageFilterISS2F

        Create a new object of the class itkBayesianClassifierInitializationImageFilterISS2F and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkBayesianClassifierInitializationImageFilterISS2F.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkBayesianClassifierInitializationImageFilterISS2F.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkBayesianClassifierInitializationImageFilterISS2F.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkBayesianClassifierInitializationImageFilterISS2F in _itkBayesianClassifierInitializationImageFilterPython:
_itkBayesianClassifierInitializationImageFilterPython.itkBayesianClassifierInitializationImageFilterISS2F_swigregister(itkBayesianClassifierInitializationImageFilterISS2F)

def itkBayesianClassifierInitializationImageFilterISS3F_New():
    return itkBayesianClassifierInitializationImageFilterISS3F.New()

class itkBayesianClassifierInitializationImageFilterISS3F(itk.itkImageToImageFilterBPython.itkImageToImageFilterISS3VIF3):
    r"""Proxy of C++ itkBayesianClassifierInitializationImageFilterISS3F class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkBayesianClassifierInitializationImageFilterISS3F_Pointer"""
        return _itkBayesianClassifierInitializationImageFilterPython.itkBayesianClassifierInitializationImageFilterISS3F___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkBayesianClassifierInitializationImageFilterISS3F_Pointer"""
        return _itkBayesianClassifierInitializationImageFilterPython.itkBayesianClassifierInitializationImageFilterISS3F_Clone(self)

    def SetMembershipFunctions(self, membershipFunction):
        r"""
        SetMembershipFunctions(self, membershipFunction)

        Parameters
        ----------
        membershipFunction: itk::VectorContainer< unsigned int,itk::SmartPointer< itk::Statistics::MembershipFunctionBase< itk::Vector< short,1 > > > > *

        """
        return _itkBayesianClassifierInitializationImageFilterPython.itkBayesianClassifierInitializationImageFilterISS3F_SetMembershipFunctions(self, membershipFunction)

    def GetModifiableMembershipFunctionContainer(self):
        r"""GetModifiableMembershipFunctionContainer(self) -> itk::VectorContainer< unsigned int,itk::SmartPointer< itk::Statistics::MembershipFunctionBase< itk::Vector< short,1 > > > > *"""
        return _itkBayesianClassifierInitializationImageFilterPython.itkBayesianClassifierInitializationImageFilterISS3F_GetModifiableMembershipFunctionContainer(self)

    def GetMembershipFunctionContainer(self, *args):
        r"""
        GetMembershipFunctionContainer(self) -> itk::VectorContainer< unsigned int,itk::SmartPointer< itk::Statistics::MembershipFunctionBase< itk::Vector< short,1 > > > > const
        GetMembershipFunctionContainer(self) -> itk::VectorContainer< unsigned int,itk::SmartPointer< itk::Statistics::MembershipFunctionBase< itk::Vector< short,1 > > > > *
        """
        return _itkBayesianClassifierInitializationImageFilterPython.itkBayesianClassifierInitializationImageFilterISS3F_GetMembershipFunctionContainer(self, *args)

    def SetNumberOfClasses(self, _arg):
        r"""
        SetNumberOfClasses(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        """
        return _itkBayesianClassifierInitializationImageFilterPython.itkBayesianClassifierInitializationImageFilterISS3F_SetNumberOfClasses(self, _arg)

    def GetNumberOfClasses(self):
        r"""GetNumberOfClasses(self) -> unsigned int"""
        return _itkBayesianClassifierInitializationImageFilterPython.itkBayesianClassifierInitializationImageFilterISS3F_GetNumberOfClasses(self)

    def GenerateOutputInformation(self):
        r"""GenerateOutputInformation(self)"""
        return _itkBayesianClassifierInitializationImageFilterPython.itkBayesianClassifierInitializationImageFilterISS3F_GenerateOutputInformation(self)
    InputMultiplyOperatorCheck = _itkBayesianClassifierInitializationImageFilterPython.itkBayesianClassifierInitializationImageFilterISS3F_InputMultiplyOperatorCheck
    
    DoubleConvertibleToProbabilityCheck = _itkBayesianClassifierInitializationImageFilterPython.itkBayesianClassifierInitializationImageFilterISS3F_DoubleConvertibleToProbabilityCheck
    
    InputHasNumericTraitsCheck = _itkBayesianClassifierInitializationImageFilterPython.itkBayesianClassifierInitializationImageFilterISS3F_InputHasNumericTraitsCheck
    
    ProbabilityHasNumericTraitsCheck = _itkBayesianClassifierInitializationImageFilterPython.itkBayesianClassifierInitializationImageFilterISS3F_ProbabilityHasNumericTraitsCheck
    
    DoublePlusInputCheck = _itkBayesianClassifierInitializationImageFilterPython.itkBayesianClassifierInitializationImageFilterISS3F_DoublePlusInputCheck
    
    __swig_destroy__ = _itkBayesianClassifierInitializationImageFilterPython.delete_itkBayesianClassifierInitializationImageFilterISS3F

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkBayesianClassifierInitializationImageFilterISS3F

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkBayesianClassifierInitializationImageFilterPython.itkBayesianClassifierInitializationImageFilterISS3F_cast(obj)

    def New(*args, **kargs):
        """New() -> itkBayesianClassifierInitializationImageFilterISS3F

        Create a new object of the class itkBayesianClassifierInitializationImageFilterISS3F and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkBayesianClassifierInitializationImageFilterISS3F.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkBayesianClassifierInitializationImageFilterISS3F.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkBayesianClassifierInitializationImageFilterISS3F.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkBayesianClassifierInitializationImageFilterISS3F in _itkBayesianClassifierInitializationImageFilterPython:
_itkBayesianClassifierInitializationImageFilterPython.itkBayesianClassifierInitializationImageFilterISS3F_swigregister(itkBayesianClassifierInitializationImageFilterISS3F)

def itkBayesianClassifierInitializationImageFilterIUC2F_New():
    return itkBayesianClassifierInitializationImageFilterIUC2F.New()

class itkBayesianClassifierInitializationImageFilterIUC2F(itk.itkImageToImageFilterBPython.itkImageToImageFilterIUC2VIF2):
    r"""Proxy of C++ itkBayesianClassifierInitializationImageFilterIUC2F class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkBayesianClassifierInitializationImageFilterIUC2F_Pointer"""
        return _itkBayesianClassifierInitializationImageFilterPython.itkBayesianClassifierInitializationImageFilterIUC2F___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkBayesianClassifierInitializationImageFilterIUC2F_Pointer"""
        return _itkBayesianClassifierInitializationImageFilterPython.itkBayesianClassifierInitializationImageFilterIUC2F_Clone(self)

    def SetMembershipFunctions(self, membershipFunction):
        r"""
        SetMembershipFunctions(self, membershipFunction)

        Parameters
        ----------
        membershipFunction: itk::VectorContainer< unsigned int,itk::SmartPointer< itk::Statistics::MembershipFunctionBase< itk::Vector< unsigned char,1 > > > > *

        """
        return _itkBayesianClassifierInitializationImageFilterPython.itkBayesianClassifierInitializationImageFilterIUC2F_SetMembershipFunctions(self, membershipFunction)

    def GetModifiableMembershipFunctionContainer(self):
        r"""GetModifiableMembershipFunctionContainer(self) -> itk::VectorContainer< unsigned int,itk::SmartPointer< itk::Statistics::MembershipFunctionBase< itk::Vector< unsigned char,1 > > > > *"""
        return _itkBayesianClassifierInitializationImageFilterPython.itkBayesianClassifierInitializationImageFilterIUC2F_GetModifiableMembershipFunctionContainer(self)

    def GetMembershipFunctionContainer(self, *args):
        r"""
        GetMembershipFunctionContainer(self) -> itk::VectorContainer< unsigned int,itk::SmartPointer< itk::Statistics::MembershipFunctionBase< itk::Vector< unsigned char,1 > > > > const
        GetMembershipFunctionContainer(self) -> itk::VectorContainer< unsigned int,itk::SmartPointer< itk::Statistics::MembershipFunctionBase< itk::Vector< unsigned char,1 > > > > *
        """
        return _itkBayesianClassifierInitializationImageFilterPython.itkBayesianClassifierInitializationImageFilterIUC2F_GetMembershipFunctionContainer(self, *args)

    def SetNumberOfClasses(self, _arg):
        r"""
        SetNumberOfClasses(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        """
        return _itkBayesianClassifierInitializationImageFilterPython.itkBayesianClassifierInitializationImageFilterIUC2F_SetNumberOfClasses(self, _arg)

    def GetNumberOfClasses(self):
        r"""GetNumberOfClasses(self) -> unsigned int"""
        return _itkBayesianClassifierInitializationImageFilterPython.itkBayesianClassifierInitializationImageFilterIUC2F_GetNumberOfClasses(self)

    def GenerateOutputInformation(self):
        r"""GenerateOutputInformation(self)"""
        return _itkBayesianClassifierInitializationImageFilterPython.itkBayesianClassifierInitializationImageFilterIUC2F_GenerateOutputInformation(self)
    InputMultiplyOperatorCheck = _itkBayesianClassifierInitializationImageFilterPython.itkBayesianClassifierInitializationImageFilterIUC2F_InputMultiplyOperatorCheck
    
    DoubleConvertibleToProbabilityCheck = _itkBayesianClassifierInitializationImageFilterPython.itkBayesianClassifierInitializationImageFilterIUC2F_DoubleConvertibleToProbabilityCheck
    
    InputHasNumericTraitsCheck = _itkBayesianClassifierInitializationImageFilterPython.itkBayesianClassifierInitializationImageFilterIUC2F_InputHasNumericTraitsCheck
    
    ProbabilityHasNumericTraitsCheck = _itkBayesianClassifierInitializationImageFilterPython.itkBayesianClassifierInitializationImageFilterIUC2F_ProbabilityHasNumericTraitsCheck
    
    DoublePlusInputCheck = _itkBayesianClassifierInitializationImageFilterPython.itkBayesianClassifierInitializationImageFilterIUC2F_DoublePlusInputCheck
    
    __swig_destroy__ = _itkBayesianClassifierInitializationImageFilterPython.delete_itkBayesianClassifierInitializationImageFilterIUC2F

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkBayesianClassifierInitializationImageFilterIUC2F

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkBayesianClassifierInitializationImageFilterPython.itkBayesianClassifierInitializationImageFilterIUC2F_cast(obj)

    def New(*args, **kargs):
        """New() -> itkBayesianClassifierInitializationImageFilterIUC2F

        Create a new object of the class itkBayesianClassifierInitializationImageFilterIUC2F and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkBayesianClassifierInitializationImageFilterIUC2F.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkBayesianClassifierInitializationImageFilterIUC2F.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkBayesianClassifierInitializationImageFilterIUC2F.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkBayesianClassifierInitializationImageFilterIUC2F in _itkBayesianClassifierInitializationImageFilterPython:
_itkBayesianClassifierInitializationImageFilterPython.itkBayesianClassifierInitializationImageFilterIUC2F_swigregister(itkBayesianClassifierInitializationImageFilterIUC2F)

def itkBayesianClassifierInitializationImageFilterIUC3F_New():
    return itkBayesianClassifierInitializationImageFilterIUC3F.New()

class itkBayesianClassifierInitializationImageFilterIUC3F(itk.itkImageToImageFilterBPython.itkImageToImageFilterIUC3VIF3):
    r"""Proxy of C++ itkBayesianClassifierInitializationImageFilterIUC3F class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkBayesianClassifierInitializationImageFilterIUC3F_Pointer"""
        return _itkBayesianClassifierInitializationImageFilterPython.itkBayesianClassifierInitializationImageFilterIUC3F___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkBayesianClassifierInitializationImageFilterIUC3F_Pointer"""
        return _itkBayesianClassifierInitializationImageFilterPython.itkBayesianClassifierInitializationImageFilterIUC3F_Clone(self)

    def SetMembershipFunctions(self, membershipFunction):
        r"""
        SetMembershipFunctions(self, membershipFunction)

        Parameters
        ----------
        membershipFunction: itk::VectorContainer< unsigned int,itk::SmartPointer< itk::Statistics::MembershipFunctionBase< itk::Vector< unsigned char,1 > > > > *

        """
        return _itkBayesianClassifierInitializationImageFilterPython.itkBayesianClassifierInitializationImageFilterIUC3F_SetMembershipFunctions(self, membershipFunction)

    def GetModifiableMembershipFunctionContainer(self):
        r"""GetModifiableMembershipFunctionContainer(self) -> itk::VectorContainer< unsigned int,itk::SmartPointer< itk::Statistics::MembershipFunctionBase< itk::Vector< unsigned char,1 > > > > *"""
        return _itkBayesianClassifierInitializationImageFilterPython.itkBayesianClassifierInitializationImageFilterIUC3F_GetModifiableMembershipFunctionContainer(self)

    def GetMembershipFunctionContainer(self, *args):
        r"""
        GetMembershipFunctionContainer(self) -> itk::VectorContainer< unsigned int,itk::SmartPointer< itk::Statistics::MembershipFunctionBase< itk::Vector< unsigned char,1 > > > > const
        GetMembershipFunctionContainer(self) -> itk::VectorContainer< unsigned int,itk::SmartPointer< itk::Statistics::MembershipFunctionBase< itk::Vector< unsigned char,1 > > > > *
        """
        return _itkBayesianClassifierInitializationImageFilterPython.itkBayesianClassifierInitializationImageFilterIUC3F_GetMembershipFunctionContainer(self, *args)

    def SetNumberOfClasses(self, _arg):
        r"""
        SetNumberOfClasses(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        """
        return _itkBayesianClassifierInitializationImageFilterPython.itkBayesianClassifierInitializationImageFilterIUC3F_SetNumberOfClasses(self, _arg)

    def GetNumberOfClasses(self):
        r"""GetNumberOfClasses(self) -> unsigned int"""
        return _itkBayesianClassifierInitializationImageFilterPython.itkBayesianClassifierInitializationImageFilterIUC3F_GetNumberOfClasses(self)

    def GenerateOutputInformation(self):
        r"""GenerateOutputInformation(self)"""
        return _itkBayesianClassifierInitializationImageFilterPython.itkBayesianClassifierInitializationImageFilterIUC3F_GenerateOutputInformation(self)
    InputMultiplyOperatorCheck = _itkBayesianClassifierInitializationImageFilterPython.itkBayesianClassifierInitializationImageFilterIUC3F_InputMultiplyOperatorCheck
    
    DoubleConvertibleToProbabilityCheck = _itkBayesianClassifierInitializationImageFilterPython.itkBayesianClassifierInitializationImageFilterIUC3F_DoubleConvertibleToProbabilityCheck
    
    InputHasNumericTraitsCheck = _itkBayesianClassifierInitializationImageFilterPython.itkBayesianClassifierInitializationImageFilterIUC3F_InputHasNumericTraitsCheck
    
    ProbabilityHasNumericTraitsCheck = _itkBayesianClassifierInitializationImageFilterPython.itkBayesianClassifierInitializationImageFilterIUC3F_ProbabilityHasNumericTraitsCheck
    
    DoublePlusInputCheck = _itkBayesianClassifierInitializationImageFilterPython.itkBayesianClassifierInitializationImageFilterIUC3F_DoublePlusInputCheck
    
    __swig_destroy__ = _itkBayesianClassifierInitializationImageFilterPython.delete_itkBayesianClassifierInitializationImageFilterIUC3F

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkBayesianClassifierInitializationImageFilterIUC3F

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkBayesianClassifierInitializationImageFilterPython.itkBayesianClassifierInitializationImageFilterIUC3F_cast(obj)

    def New(*args, **kargs):
        """New() -> itkBayesianClassifierInitializationImageFilterIUC3F

        Create a new object of the class itkBayesianClassifierInitializationImageFilterIUC3F and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkBayesianClassifierInitializationImageFilterIUC3F.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkBayesianClassifierInitializationImageFilterIUC3F.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkBayesianClassifierInitializationImageFilterIUC3F.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkBayesianClassifierInitializationImageFilterIUC3F in _itkBayesianClassifierInitializationImageFilterPython:
_itkBayesianClassifierInitializationImageFilterPython.itkBayesianClassifierInitializationImageFilterIUC3F_swigregister(itkBayesianClassifierInitializationImageFilterIUC3F)

from itk.support import helpers
import itk.support.types as itkt
from typing import Sequence, Tuple, Union

@helpers.accept_array_like_xarray_torch
def bayesian_classifier_initialization_image_filter(*args: itkt.ImageLike,  membership_functions=..., number_of_classes: int=...,**kwargs)-> itkt.ImageSourceReturn:
    """Functional interface for BayesianClassifierInitializationImageFilter"""
    import itk

    kwarg_typehints = { 'membership_functions':membership_functions,'number_of_classes':number_of_classes }
    specified_kwarg_typehints = { k:v for (k,v) in kwarg_typehints.items() if kwarg_typehints[k] is not ... }
    kwargs.update(specified_kwarg_typehints)


    instance = itk.BayesianClassifierInitializationImageFilter.New(*args, **kwargs)

    return instance.__internal_call__()

def bayesian_classifier_initialization_image_filter_init_docstring():
    import itk
    from itk.support import template_class

    filter_class = itk.ITKClassifiers.BayesianClassifierInitializationImageFilter
    bayesian_classifier_initialization_image_filter.process_object = filter_class
    is_template = isinstance(filter_class, template_class.itkTemplate)
    if is_template:
        filter_object = filter_class.values()[0]
    else:
        filter_object = filter_class

    bayesian_classifier_initialization_image_filter.__doc__ = filter_object.__doc__



